<?php

/**
 * Created by PhpStorm.
 * User: roc
 * Date: 2018/8/10
 * Time: 15:36
 */
namespace kwy\kwy_third_merchant_sdk\LePass;
use kwy\kwy_third_merchant_sdk\Common\Util;

class LePass
{
    private $oss_url = 'http://weiwoju.oss-cn-hangzhou.aliyuncs.com/uploads/';

    private $test = [
        'agent_id' => '10',
        'key' => '17B10781A8C5178870197906F71749D8',
        'upload_pic' => 'http://saas.lepass.cn/api/picture/upload', //图片上传 MA001
        'regregister_url' => 'http://saas.lepass.cn/api/merchant/register', //商户进件 MA002
        'open_url' => 'http://saas.lepass.cn/api/merchant/open',    //商户开通业务 MA003
        'update_url' => 'http://saas.lepass.cn/api/merchant/update',    //商户信息修改 MA004
        'query_url' => 'http://saas.lepass.cn/api/merchant/info_qry',   //商户信息查询 MA005
        'update_account' => 'http://pos.lepass.cn/api/merchant/update_account',
        'apply_mybank_bluesea' => 'http://pos.lepass.cn/api/merchant/apply_mybank_bluesea.do',
        'sub_query_url' => 'http://saas.lepass.cn/api/submch/query',    //商户上报情况查询
    ];

    private $product = [
        'upload_pic' => '/picture/upload',   //图片上传 MA001
        'regregister_url' => '/merchant/register',   //商户进件 MA002
        'open_url' => '/merchant/open', //商户开通业务 MA003
        'update_url' => '/merchant/update', //商户信息修改 MA004
        'query_url' => '/merchant/info_qry',    //商户信息查询 MA005
        'wxpayconfig' => '/wechat/wxpayconfig', //商户支付参数
        'wxpayconfig_qry' => '/wechat/wxpayconfig_qry',
        'update_account' => '/merchant/update_account',    //
        'apply_mybank_bluesea' => '/merchant/apply_mybank_bluesea.do',
        'sub_query_url' => '/submch/query',    //商户上报情况查询
    ];

    private $agent_id= '';  //代理商渠道编号

    private $key = '';  //代理商秘钥

//    private $host = 'https://saas-mch.leshuazf.com/api';    //乐刷新版进件域名
    private $host = 'https://saas-mch.leshuazf.com/apiv2';    //乐刷新版进件域名

    //版本
    private $version = "2.0";

    /**
     * @return string
     */
    public function getVersion() {
        return $this->version;
    }

    /**
     * @param string $version
     */
    public function setVersion($version) {
        $this->version = $version;
    }


    /**
     * 是否正式环境，默认是正式环境
     * @var bool
     */
    private $is_pro = true;

    /**
     * 设置是否走的正式环境
     * @param bool $isPro 默认正式环境
     */
    public function setIsPro($isPro = true){
        $this->is_pro = $isPro;
    }

    /**
     * 设置乐刷域名
     * @param $host
     */
    public function setHost($host){
        $this->host = $host;
    }

    /**
     * 设置代理商渠道编号
     * @param $agent_id
     */
    public function setAgentId($agent_id){
        $this->agent_id = $agent_id;
    }

    /**
     * 设置代理商秘钥
     * @param $key
     */
    public function setKey($key){
        $this->key = $key;
    }

    /**
     * 图片上传
     * @param $picUrl 本地图片路径
     * @param $type 图片类型
     * @return mixed
     * @throws \Exception
     */
    public function uploadPic($picUrl,$type){
        $url = $this->getUrl('upload_pic');

        //文件后缀
        $arr = explode('.', $picUrl);
        $picSuffix = end($arr);
        //文件后缀

        ##格式化图片路径
        $pic_url = str_replace($this->oss_url,'',$picUrl);
        $pic_url = $this->oss_url.$pic_url;

        ##下载图片到本地服务器
        $pic_url = Util::downloadPic($pic_url);
        $pic =  Util::downloadFile($pic_url,$picSuffix);
        if(!file_exists($pic)){
            throw new \Exception('不存在的图片: '.$type.$picUrl);
        }
        ##判断图片大小，超过1M需要做裁剪
        if(filesize($pic) > 1024000){
            $original_pic = $pic;
            $pic = Util::get_thumb_img($original_pic,1024);
            @unlink($original_pic);
        }
        
        $data['fileMD5'] = md5_file($pic);
        $json_data = json_encode($data,320);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['media'] = curl_file_create($pic);
        $params['sign'] = $this->getSign($json_data);

        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        @unlink($pic);  //删除本地图片
        if(empty($result)){
            throw new \Exception($type.'图片上传至乐刷失败1,返回数据:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            throw new \Exception($type.'图片上传至乐刷失败2:'.$result['respMsg']);
        }
        return $result['data']['photoUrl'];
    }


    /**
     * 查询商户申请状态
     * @param $mch_id
     * @return mixed
     *          array(5) {
    ["merchantId"] => string(10) "6605008515"
    ["respDateTime"] => string(19) "2019-02-22 15:37:51"
    ["baseInfo"] => array(2) {
    ["merchantName"] => string(21) "沙县国际大酒店"
    ["dirAgentId"] => string(2) "10"
    }
    ["auditInfo"] => array(4) {
    ["auditMsg"] => string(0) ""
    ["auditStatus"] => string(8) "AUDITING"
    ["auditDateTime"] => string(0) ""
    ["mchLevel"] => string(9) "AUTHENTIC"
    }
    ["rateInfo"] => array(2) {
    ["wechat"] => array(1) {
    ["t1"] => int(30)
    }
    ["alipay"] => array(1) {
    ["t1"] => int(30)
    }
    }
    }
     * @throws \Exception
     */
    public function queryMch($mch_id){
        $url = $this->getUrl('query');

        $data = [
            'merchantId' => $mch_id,
        ];

        $json_data = json_encode($data);

        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => date("YmdHis"),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;
        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('开通乐刷商户失败,返回数据异常:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            throw new \Exception('开通乐刷商户失败:'.$result['respMsg']);
        }
//        AUDITING: 审核中 PASSED: 审核通过 REJECTED: 审核拒绝 UNKNOWN: 未知
//        BASICS: 基础等级 AUTHENTIC: 认证等级 ADVANCED: 高级等级 UNKNOWN: 未知
        return $result['data'];
    }

    /**
     * 商户上报情况查询
     * @param $mch_id
     * @param $type
     * @return mixed
     * @throws \Exception
     */
    public function querySubMch($mch_id,$type){
        $url = $this->getUrl('sub_query');

        $data = [
            'merchantId' => $mch_id,
            'subMchType' => $type
        ];

        $json_data = json_encode($data);

        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => date("YmdHis"),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;
        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('查询乐刷商户上报状态失败,返回数据异常:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            throw new \Exception('查询乐刷商户上报状态失败:'.$result['respMsg']);
        }
//        AUDITING: 审核中 PASSED: 审核通过 REJECTED: 审核拒绝 UNKNOWN: 未知
//        BASICS: 基础等级 AUTHENTIC: 认证等级 ADVANCED: 高级等级 UNKNOWN: 未知
        return $result['data'];
    }

    /**
     * 进件开户
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function register($data){
        $url = $this->getUrl('register');

        //格式化数据
        $data = $this->getRequestData($data);

        $json_data = json_encode($data,320);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;

        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('开通乐刷商户失败,返回数据异常:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            dlert3('param:'.var_export($params,true).PHP_EOL.'result:'.var_export($result,true));
            throw new \Exception('开通乐刷商户失败:'.$result['respMsg']);
        }
        return $result['data'];
    }

    /**
     * 更新商户信息
     * @param $mch_id
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function update($mch_id,$data){
        $url = $this->getUrl('update');

        $data['merchantId'] = $mch_id;
        if($data['legalPerson']){
            unset($data['legalPerson']['legalName'],$data['legalPerson']['idCardNo']);
        }
        if($data['licenseInfo']){
            unset($data['licenseInfo']['licenseFullName'],$data['licenseInfo']['licenseStart'],$data['licenseInfo']['licenseEnd']);
        }

        if($data['wechatInfo']){
            unset($data['wechatInfo']);
        }

        //格式化数据
        $data = $this->getRequestData($data);

        $json_data = json_encode($data,320);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];

        $params['sign'] = $this->getSign($json_data);

        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('乐刷修改商户信息失败1,返回数据:'.$result_json);
        }

        if(!in_array($result['respCode'],['000000','000011','000022'])){
            throw new \Exception('乐刷修改商户信息失败2:'.$result['respMsg']);
        }
        switch ($result['respCode']){
            case '000011':
                $status = '审核成功';
                break;
            default :
                $status = '待审核';

        }
        $result['mch_status'] = $status;
        return $result;
    }

    /**
     * 商户开通业务
     * @param $mch_id
     * @param $wx_t1_fee    微信t1费率
     * @param $ali_t1_fee   支付宝t1费率
     * @return mixed
     * @throws \Exception
     */
    public function open($mch_id,$wx_t1_fee,$ali_t1_fee){
        $url = $this->getUrl('open');
        $data = [
            'merchantId' => $mch_id,
            'fee' => [
                'openType' => 1,
                'weixin' => [
                    't1' => [
                        'rate' => $wx_t1_fee
                    ]
                ],
                'alipay' => [
                    't1' => [
                        'rate' => $ali_t1_fee
                    ]
                ],
            ],

        ];
        foreach($data as $k => $v){
            if(is_array($v)){
                foreach($v as $k2 => $v2){
                    if(empty($v2)) unset($data[$k][$k2]);
                }
            }else{
                if(empty($v)) unset($data[$k]);
            }
        }
        $json_data = json_encode($data);

        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['sign'] = $this->getSign($json_data);

        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('开通微信、支付宝业务失败,返回数据异常:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            throw new \Exception('开通微信、支付宝业务失败:'.$result['respMsg']);
        }
        return $result;
    }

    public function openUnion($mch_id){
        $url = $this->getUrl('open');
        $data = [
            'merchantId' => $mch_id,
            'fee' => [
                'openType' => 4,
                'unionScan' => [    //银联扫码费率 -大于 1000
                    't1Credit' => [
                        'rate' => 60,   //单位:万分之一,如60表示按0.6%收费，必传
//                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
//                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],   //次日结算贷记卡费率(刷卡或银 联扫码支付必传)
                    't1Debit' => [
                        'rate' => 60,   //单位:万分之一,如60表示按0.6%收费，必传
//                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
//                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],    //次日结算借记卡费率(刷卡或银 联扫码支付必传)
                    't1OverSee' => [
                        'rate' => 300,   //单位:万分之一,如60表示按0.6%收费，必传
//                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
//                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],  //次日结算境外卡费率(刷卡或银 联扫码支付必传)
                ],
                /*'unionScan2' => [    //银联扫码费率 -小于 1000
                    't1Credit' => [
                        'rate' => '',   //单位:万分之一,如60表示按0.6%收费，必传
                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],   //次日结算贷记卡费率(刷卡或银 联扫码支付必传)
                    't1Debit' => [
                        'rate' => '',   //单位:万分之一,如60表示按0.6%收费，必传
                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],    //次日结算借记卡费率(刷卡或银 联扫码支付必传)
                    't1OverSee' => [
                        'rate' => '',   //单位:万分之一,如60表示按0.6%收费，必传
                        'minCharge' => '',   //单位:万分之一分，如60,0000表示每 笔交易最低收费0.6元非必传
                        'maxCharge' => '',   //单位:万分之一分，如30,00,0000表 示每笔交易最高收费30元
                    ],  //次日结算境外卡费率(刷卡或银 联扫码支付必传)
                ],*/
            ],

        ];
        dump($data);
        foreach($data as $k => $v){
            if(is_array($v)){
                foreach($v as $k2 => $v2){
                    if(empty($v2)) unset($data[$k][$k2]);
                }
            }else{
                if(empty($v)) unset($data[$k]);
            }
        }
        $json_data = json_encode($data);

        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['sign'] = $this->getSign($json_data);

        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('开通微信、支付宝业务失败,返回数据异常:'.$result_json);
        }
        if($result['respCode'] != '000000'){
            throw new \Exception('开通微信、支付宝业务失败:'.$result['respMsg']);
        }
        return $result;
    }

    /**
     * 配置支付appid
     * @param $mch_id   子商户商户号
     * @param $appid    支付公众号appid
     * @return bool
     * @throws \Exception
     */
    public function addSubdevConfig($mch_id,$appid){
        $url = $this->getUrl('wxpayconfig');
        $data = [
            'merchantId' => $mch_id,
            'configType' => 1,
            'sub_appid' => $appid
        ];
        $json_data = json_encode($data);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['sign'] = $this->getSign($json_data);
        $result = $this->postCurl($url,$params);
        $re_obj = json_decode($result,true);
        if(empty($re_obj)){
            throw new \Exception('配置appid失败,返回数据异常:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            throw new \Exception('配置支付公众号失败:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * 配置支付目录
     * @param $mch_id   子商户商户号
     * @param $path    支付目录
     * @return bool
     * @throws \Exception
     */
    public function addPathConfig($mch_id,$path){
        $url = $this->getUrl('wxpayconfig');
        $data = [
            'merchantId' => $mch_id,
            'configType' => 3,
            'jsapi_path' => $path
        ];
        $json_data = json_encode($data);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
//        echo $json_data;die;
        $params['sign'] = $this->getSign($json_data);
        $result = $this->postCurl($url,$params);
        $re_obj = json_decode($result,true);
        if(empty($re_obj)){
            throw new \Exception('配置appid失败,返回数据异常:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            throw new \Exception('开通微信、支付宝业务失败:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * 查询微信配置
     * @param $mch_id   子商户商户号
     * @return bool
     * @throws \Exception
     */
    public function queryWxConfig($mch_id){
        $url = $this->getUrl('wxpayconfig_qry');
        $data = [
            'merchantId' => $mch_id,
        ];
        $json_data = json_encode($data);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['sign'] = $this->getSign($json_data);
        $result = $this->postCurl($url,$params);
        $re_obj = json_decode($result,true);
        if(empty($re_obj)){
            throw new \Exception('配置appid失败,返回数据异常:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            throw new \Exception('开通微信、支付宝业务失败:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * 微信小微商户关注功能配置
     * @param string $mch_id   子商户mch_id
     * @param string $appid    支付appid
     * @param string $subscribe_appid  关注appid
     * @return bool
     * @throws \Exception
     */
    public function addRecommendConf($mch_id,$appid,$subscribe_appid){
        $url = $this->getUrl('wxpayconfig');
        $data = [
            'merchantId' => $mch_id,
            'configType' => 2,
            'sub_appid' => $appid,
            'subscribe_appid' => $subscribe_appid,
        ];
        $json_data = json_encode($data);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $params['sign'] = $this->getSign($json_data);

        $result = $this->postCurl($url,$params);
        $re_obj = json_decode($result,true);
        if(empty($re_obj)){
            throw new \Exception('配置appid失败,返回数据异常:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            if($re_obj['data'] == '推荐关注公众号已存在，不能重复修改.'){
                return $re_obj;
            }
            if($re_obj['respMsg'] == '失败 - 推荐关注公众号已存在，不能重复修改.'){
                return $re_obj;
            }
            throw new \Exception('配置关注公众号失败:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * 乐刷商户改卡操作
     * @param $mch_id
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function changeBankCard($mch_id,$data){
        $url = $this->getUrl('update_account');

        $base = [
            'merchantId' => $mch_id,
        ];
        if(empty($data['account'])){
            throw new \Exception('没有银行卡数据');
        }
        $post_data = [
            'base' => $base,
            'account' => $data['account'],
        ];
        foreach($post_data as $k => $v){
            if(is_array($v)){
                foreach($v as $k2 => $v2){
                    if(empty($v2)) unset($post_data[$k][$k2]);
                }
            }else{
                if(empty($v)) unset($post_data[$k]);
            }
        }
        $json_data = json_encode($post_data);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
//            'version' => '1.0', //版本号,目前固定值1.0
            'version' => $this->getVersion(), //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];

        $pic_arr = [
            'bank_card_front_pic' => 'bankCardFrontPic',    //银行卡正面(如是对公账户，开户许可证)(开通扫码支付必填)
        ];
        $tmpPic = [];
        foreach($pic_arr as $k => $v){
            if(!empty($data[$k])){
                $pic_url = str_replace($this->oss_url,'',$data[$k]);
                $pic_url = $this->oss_url.$pic_url;
                $pic =  Util::download($pic_url,true);
                if(!file_exists($pic)){
                    throw new \Exception('no '.$v);
                }


                if(filesize($pic) > 1024000){
                    $original_pic = $pic;
                    $pic = Util::get_thumb_img($original_pic,1024);
                    @unlink($original_pic);
                }

                $tmpPic[] = $pic;
                $params[$v] = curl_file_create($pic);
            }
        }
        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;
        $result = $this->postCurl($url,$params);
        dlert3($params);dlert3($result);dlert3($url);
        $re_obj = json_decode($result,true);
        foreach($tmpPic as $v){
            @unlink($v);
        }
        if(empty($re_obj)){
            throw new \Exception('乐刷修改银行卡数据失败1,返回数据:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            throw new \Exception('乐刷修改银行卡数据失败2:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * 乐刷打款通知
     * @param $bill_no
     * @param string $type
     * @return mixed
     * @throws \Exception
     */
    public function querySettlementOrder($bill_no,$type='t1'){
        $url = 'http://jh.yeahka.com/open-api/agent/settlement-order';

        $params = [
            'agentId' => $this->getAgentId(),
            'billId' => $bill_no,
            'type' => $type,
        ];
        $signData = $params;
        $signData['key'] = $this->getKey();
        $signStr = http_build_query($signData);
        $sign = md5($signStr);
        $params['sign'] = $sign;
        $result_json = $this->postCurl($url,$params);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('查询打款记录失败1,返回数据:'.$result_json);
        }
        if($result['error_code'] != '0'){
            throw new \Exception('查询打款记录失败2:'.$result['error_msg']);
        }
        return $result['data'];
    }

    /**
     * 乐刷打款失败查询
     * @param $date 日期  打款单的创建日期 “2019-03-02”
     * @param string $type  类型  “T0”、“T1” 、“Withdraw”
     * @param int $pageNo  页码(页码超出总页数后返回第一页)
     * @return mixed
     * @throws \Exception
     */
    public function queryAgentFailSettlementOrder($date,$type='T1',$pageNo=1){
        $url = 'http://jh.yeahka.com/open-api/agent/agent-fail-settlement-order';

        $data = [
            'date' => $date,
            'type' => $type,
            'pageNo' => $pageNo,
        ];
        //格式化数据
        $data = $this->getRequestData($data);

        $json_data = json_encode($data,320);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
            'version' => '1.0', //版本号,目前固定值1.0
            'reqSerialNo' => $this->getReqSerialNo(),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];
        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;

        $result_json = $this->postCurl($url,$params,false);
        $result = json_decode($result_json,true);
        if(empty($result)){
            throw new \Exception('乐刷打款失败订单查询失败,返回数据异常:'.$result_json);
        }
        if($result['error_code'] != '0'){
            dlert3('param:'.var_export($params,true).PHP_EOL.'result:'.var_export($result,true));
            throw new \Exception('乐刷打款失败订单查询失败:'.$result['error_msg']);
        }
        return $result;
    }

    /**
     * 乐刷商户申请蓝海行动
     * @param $mch_id
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function applyMyBankBlueSea($mch_id,$data){
        $url = $this->getUrl('apply_mybank_bluesea');
        $base = [
            'merchantId' => $mch_id,
        ];
        $post_data = [
            'base' => $base,
            'myBankAddress' => $data['myBankAddress'],
        ];
        foreach($post_data as $k => $v){
            if(is_array($v)){
                foreach($v as $k2 => $v2){
                    if(empty($v2)) unset($post_data[$k][$k2]);
                }
            }else{
                if(empty($v)) unset($post_data[$k]);
            }
        }
        $json_data = json_encode($post_data,JSON_UNESCAPED_UNICODE);
        $params = [
            'agentId' => $this->getAgentId(),  //代理商编号，由乐刷分配的接入方唯一标识，明文传输。测试环境固定为10。签名串
            'version' => '1.0', //版本号,目前固定值1.0
            'reqSerialNo' => date("YmdHis"),    //请求流水号(全局唯一，建议为yyyymmddXXXXXXXX，其中 XXXXXXXX 为 8 位顺 序,目前只作为定位请求用)
            'data' => $json_data,   //Json报文主体
        ];

        $sign = $this->getSign($json_data);
        $params['sign'] = $sign;

        $pic_arr = [
            'cashierDeskForAliPay' => 'cashierDeskForAliPay',    //收银台照片含支付宝物料
            'thirdPlatformSettledPic' => 'thirdPlatformSettledPic',  //第三方平台入驻图
        ];
        $tmpPic = [];
        foreach($pic_arr as $k => $v){
            if(!empty($data[$k])){
                $pic_url = str_replace($this->oss_url,'',$data[$k]);
                $pic_url = $this->oss_url.$pic_url;
                $pic =  Util::download($pic_url,true);
                if(!file_exists($pic)){
                    throw new \Exception('no '.$v);
                }

                if(filesize($pic) > 1024000){
                    $original_pic = $pic;
                    $pic = Util::get_thumb_img($original_pic,1024);
                    @unlink($original_pic);
                }

                $tmpPic[] = $pic;
                $params[$v] = curl_file_create($pic);
            }
        }
        $result = $this->postCurl($url,$params);
        $re_obj = json_decode($result,true);
        foreach($tmpPic as $v){
            @unlink($v);
        }

        dump($params);dump($re_obj);
        if(empty($re_obj)){
            throw new \Exception('乐刷申请蓝海行动失败1,返回数据:'.$result);
        }
        if($re_obj['respCode'] != '000000'){
            throw new \Exception('乐刷申请蓝海行动失败2:'.$re_obj['respMsg']);
        }
        return $re_obj;
    }

    /**
     * post请求
     * @param $url
     * @param $jsonStr
     * @param $multiArr
     * @return bool|mixed
     */
    private function postCurl($url,$jsonStr, $multiArr = true){
        $ch = curl_init();
        $header[] = "Accept-Charset: utf-8";
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
        curl_setopt($ch, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4 );//强制ipv4解析
        curl_setopt($ch, CURLOPT_AUTOREFERER, 1);

        curl_setopt($ch, CURLOPT_TIMEOUT,60);   //只需要设置一个秒的数量就可以
//        curl_setopt($ch, CURLOPT_PROXY, "127.0.0.1"); //代理服务器地址
//        curl_setopt($ch, CURLOPT_PROXYPORT,'8888'); //代理服务器端口

        //如果不用multiArr提交数据，那么转为application/x-www-form-urlencoded型号（键值对）
        if($multiArr === false){
            $jsonStr = http_build_query($jsonStr);
        }
        curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonStr);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $tmpInfo = curl_exec($ch);
        if (curl_errno($ch)) {
            curl_close($ch);
            return false;
        }else{
            curl_close($ch);
            return $tmpInfo;
        }

    }

    /**
     * 获取请求通讯时的签名
     * @param $json_str
     * @return string
     */
    private function getSign($json_str){
        $key = $this->getKey();
        $sign = base64_encode(md5('lepos'.$key.$json_str));
        return $sign;
    }

    /**
     * 获取代理商编号
     * @return mixed
     */
    private function getAgentId(){
        if($this->is_pro !== true){
            return $this->test['agent_id'];
        }else{
            return $this->agent_id;
        }
    }

    /**
     * 获取秘钥
     * @return mixed
     */
    private function getKey(){
        if($this->is_pro !== true){
            return $this->test['key'];
        }else{
            return $this->key;
        }
    }

    /**
     * 获取请求地址
     * @param $type
     * @return string
     * @throws \Exception
     */
    private function getUrl($type){
        if($this->is_pro !== true){
            switch ($type){
                case 'upload_pic':  //图片上传
                    return $this->test['upload_pic'];
                    break;
                case 'query':
                    return $this->test['query_url'];
                    break;
                case 'sub_query':
                    return $this->test['sub_query_url'];
                    break;
                case 'update':
                    return $this->test['update_url'];
                    break;
                case 'register':
                    return $this->test['regregister_url'];
                break;
                case 'open':
                    return $this->test['open_url'];
                break;
                case 'apply_mybank_bluesea':
                    return $this->test['apply_mybank_bluesea'];
                break;
                default:
                    throw new \Exception('无此接口');
            }
        }else{
            switch ($type){
                case 'upload_pic':  //图片上传
                    $host = $this->getProductHost();
                    return $host.$this->product['upload_pic'];
                    break;
                case 'query':
                    $host = $this->getProductHost();
                    return $host.$this->product['query_url'];
                    break;
                case 'sub_query':
                    $host = $this->getProductHost();
                    return $host.$this->product['sub_query_url'];
                    break;
                case 'update':
                    $host = $this->getProductHost();
                    return $host.$this->product['update_url'];
                    break;
                case 'register':
                    $host = $this->getProductHost();
                    return $host.$this->product['regregister_url'];
                    break;
                case 'open':
                    $host = $this->getProductHost();
                    return $host.$this->product['open_url'];
                    break;
                case 'wxpayconfig':
                    $host = $this->getProductHost();
                    return $host.$this->product['wxpayconfig'];
                    break;
                case 'wxpayconfig_qry':
                    $host = $this->getProductHost();
                    return $host.$this->product['wxpayconfig_qry'];
                    break;
                case 'update_account':
                    $host = $this->getProductHost();
                    return $host.$this->product['update_account'];
                    break;
                case 'apply_mybank_bluesea':
                    $host = $this->getProductHost();
                    return $host.$this->product['apply_mybank_bluesea'];
                break;
                default:
                    throw new \Exception('无此接口');
            }
        }
    }

    /**
     * 获取乐刷进件域名
     * @return string
     */
    public function getProductHost(){
        return $this->host;
    }

    /**
     * 获取流水号
     * @return string
     */
    private function getReqSerialNo(){
        return date("YmdHis").mt_rand(1000,9999);
    }

    /**
     * 获取请求的data数据（移除空数据）
     * @param $data
     * @return mixed
     */
    public function getRequestData($data){
        foreach($data as $k => $v){
            if(is_array($v)){
                foreach($v as $k2 => $v2){
                    if(empty($v2) && $v2 != 0) unset($data[$k][$k2]);
                }
                if(empty($data[$k])) unset($data[$k]);
            }else{
                if(empty($v) && $v != 0) unset($data[$k]);
            }
        }
        return $data;
    }

    /**
     * 获取行业
     * @param $industry_id
     * @return string
     */
    public static function getBusiness($industry_id){
        '557    餐饮  快餐
555 餐饮  火锅
556 餐饮  烧烤
560 餐饮  小吃/熟食
551 餐饮  其他中餐
553 餐饮  日韩/东南亚菜
552 餐饮  西餐
554 餐饮  咖啡厅
562 餐饮  甜品饮品
561 餐饮  烘焙糕点
209 线下零售    便利店
292 线下零售    食品生鲜    请简述具体售卖的商品1.销售食用农产品：无需特殊资质2.销售加工非食用农产品需提供：《食品流通许可证》或《食品卫生许可证》或《食品经营许可证》或《保健食品经营卫生许可证》（四选一）
319 线下零售    数码电器/电脑办公
293 线下零售    家具建材/家居厨具
297 线下零售    服饰箱包 
116 线下零售    运动户外    
294 线下零售    美妆个护
123 线下零售    计生用品
296 线下零售    汽车用品
323 线下零售    图书音像/文具乐器
298 线下零售    钟表眼镜
305 线下零售    宠物/宠物用品
295 线下零售    礼品鲜花/农资绿植
586 线下零售    批发业 请简述具体售卖的商品  一、食盐批发：食盐批发许可证+国务院盐业主管机构备案证明文件
二、医疗器械批发：批发第二类医疗器械需取得食品药品监督管理部门备案证明；批发第三类医疗器械需取得《医疗器械经营许可证》
三、批发报纸、期刊、图书、音像制品、电子出版物等：《出版物经营许可证》
299 居民生活/商业服务   婚庆/摄影
306 居民生活/商业服务   装饰/设计
320 居民生活/商业服务   家政/维修服务
321 居民生活/商业服务   广告/会展/活动策划
324 居民生活/商业服务   苗木种植/园林绿化
148 休闲娱乐    运动健身场馆
580 休闲娱乐    美发/美容/美甲店   请简述具体提供的服务如涉及医疗美容技术内容需提供《医疗机构执业许可证》
300 休闲娱乐    俱乐部/休闲会所
577 休闲娱乐    酒吧
301 交通运输/票务旅游   旅馆/酒店/度假区
307 交通运输/票务旅游   娱乐票务';

        $arr = [
            '46' => '560',
            '108' => '209',
            '107' => '209',
            '122' => '209',
            '83' => '324',
            '82' => '324',
            '66' => '299',
            '56' => '301',
            '52' => '307',
            '43' => '580',
        ];
        $wx_industry_id = $arr[$industry_id];
        if(empty($wx_industry_id)) $wx_industry_id = '560';

        return $wx_industry_id;
    }
}